package com.ruoyi.member.controller;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import javax.servlet.http.HttpServletResponse;

import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.member.domain.MemberAddress;
import com.ruoyi.member.service.IMemberAddressService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 博主收货地址Controller
 *
 * @author pqz
 * @date 2025-03-17
 */
@RestController
@RequestMapping("/member/address")
public class MemberAddressController extends BaseController {
    @Autowired
    private IMemberAddressService memberAddressService;

    /**
     * 根据用户id查询博主地址列表（不分页）
     *
     * @param userId 用户id
     * @return com.ruoyi.common.core.domain.AjaxResult
     * @author PQZ
     * @date 10:39 2025/3/29
     **/
    @GetMapping("/listByUserId")
    public AjaxResult listByUserId(@RequestParam("userId") Long userId) {
        return success(memberAddressService.listByUserId(userId));
    }

    /**
     * 根据地址id查询博主地址详细信息
     *
     * @param id 地址id
     * @return com.ruoyi.common.core.domain.AjaxResult
     * @author PQZ
     * @date 10:43 2025/3/29
     **/
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") String id) {
        return success(memberAddressService.getById(id));
    }

    /**
     * 新增博主收货地址
     *
     * @param memberAddress {@link MemberAddress}
     * @return com.ruoyi.common.core.domain.AjaxResult
     * @author PQZ
     * @date 10:43 2025/3/29
     **/
    @Log(title = "博主收货地址", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody MemberAddress memberAddress) {
        return toAjax(memberAddressService.save(memberAddress));
    }

    /**
     * 修改博主收货地址
     *
     * @param memberAddress {@link MemberAddress}
     * @return com.ruoyi.common.core.domain.AjaxResult
     * @author PQZ
     * @date 10:44 2025/3/29
     **/
    @Log(title = "博主收货地址", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody MemberAddress memberAddress) {
        return toAjax(memberAddressService.updateById(memberAddress));
    }

    /**
     * 删除博主收货地址
     *
     * @param ids id
     * @return com.ruoyi.common.core.domain.AjaxResult
     * @author PQZ
     * @date 10:45 2025/3/29
     **/
    @Log(title = "博主收货地址", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable String[] ids) {
        List<String> list = new ArrayList<>(Arrays.asList(ids));
        return toAjax(memberAddressService.removeByIds(list));
    }
}
