package com.ruoyi.member.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.ruoyi.common.core.domain.DlBaseEntity;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.member.domain.MemberBusiCard;
import com.ruoyi.member.mapper.MemberBusiCardMapper;
import com.ruoyi.member.service.IMemberBusiCardService;
import com.ruoyi.member.vo.MemberBusiCardVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Date;
import java.util.List;

/**
 * 博主名片Service业务层处理
 *
 * @author pqz
 * @date 2025-03-21
 */
@Service
public class MemberBusiCardServiceImpl extends ServiceImpl<MemberBusiCardMapper, MemberBusiCard> implements IMemberBusiCardService {
    @Autowired
    private MemberBusiCardMapper memberBusiCardMapper;

    /**
     * 分页查询博主名片信息
     *
     * @param pageReqVO {@link MemberBusiCard}
     * @param page      分页参数
     * @return com.baomidou.mybatisplus.core.metadata.IPage<com.ruoyi.member.domain.MemberBusiCard>
     * @author PQZ
     * @date 21:46 2025/3/21
     **/
    @Override
    public IPage<MemberBusiCard> queryListPage(MemberBusiCard pageReqVO, Page<MemberBusiCard> page) {
        return memberBusiCardMapper.queryListPage(pageReqVO, page);
    }

    /**
     * 通过id查询博主名片信息
     *
     * @param id 博主名片id
     * @return com.ruoyi.member.vo.MemberBusiCardVO
     * @author PQZ
     * @date 22:36 2025/3/21
     **/
    @Override
    public MemberBusiCardVO queryById(String id) {
        return memberBusiCardMapper.queryById(id);
    }

    /**
     * 通过用户id查询名片
     *
     * @param userId 用户表id
     * @return java.util.List<com.ruoyi.member.domain.MemberBusiCard>
     * @author PQZ
     * @date 10:49 2025/3/22
     **/
    @Override
    public List<MemberBusiCard> queryListByUserId(Long userId) {
        LambdaQueryWrapper<MemberBusiCard> lambdaQueryWrapper = new LambdaQueryWrapper<>();
        lambdaQueryWrapper.eq(DlBaseEntity::getDelFlag,0)
                .eq(MemberBusiCard::getApprovalStatus,"1")
                .eq(MemberBusiCard::getUserId,userId);
        return list(lambdaQueryWrapper);
    }

    /**
     * 审核博主名片信息
     *
     * @param card {@link MemberBusiCard}
     * @author PQZ
     * @date 23:17 2025/3/21
     **/
    @Override
    public void checkBusiCard(MemberBusiCard card) {
        //获取当前登录用户id
        Long userId = SecurityUtils.getUserId();
        //当前时间
        Date nowDate = new Date();
        card.setApprovalUserId(userId);
        card.setApprovalTime(nowDate);
        updateById(card);
    }


}
